[![Build Status](https://travis-ci.com/mojikimino/mkn.svg?branch=master)](https://travis-ci.com/mojikimino/mkn)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn?ref=badge_shield)

# A sample PyPI project

## License
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fmojikimino%2Fmkn?ref=badge_large)